@@ -10,7 +10,7 @@ from btrader.core.TradeWorker import TradeWorker
 
 class ComputeWorker (StoppableThread):
 
-  def __init__ (self, trader_matrix, trader_lock, queue, queue_lock, config, trading_lock, trading_queue, client, counter, level=logging.DEBUG, log_file=None, *args, **kwargs):
+  def __init__ (self, trader_matrix, trader_lock, queue, queue_lock, config, trading_lock, trading_queue, client, counter, stepDict, level=logging.DEBUG, log_file=None, *args, **kwargs):
     super (ComputeWorker, self).__init__(*args, **kwargs)
     self.__logger           = Logger(name="ComputeWorker", level=level, filename=log_file)
     self.__traderMatrix     = trader_matrix
@@ -26,6 +26,7 @@ class ComputeWorker (StoppableThread):
     self.__client           = client
     self.counter            = counter
     self.maxCount           = self.__config["TRADING"]["EXECUTION_CAP"] if self.__config["TRADING"]["EXECUTION_CAP"] > 0 else float('inf')
+    self.__stepDict         = stepDict
 
   @property
   def tradingEnabled (self):
@@ -39,6 +40,10 @@ class ComputeWorker (StoppableThread):
   def client (self):
     return self.__client
 
+  def correctQuantity (self, quantity, symbol):
+    step = self.__stepDict[symbol]
+    return round (quantity, -int(f'{step:e}'.split('e')[-1]))
+
   def run (self, *args, **kwargs):
     while self.running:
       self.__queueLock.acquire()
@@ -78,7 +83,7 @@ class ComputeWorker (StoppableThread):
     for action in deal.getActions():
       self.logger.info ("{} {} from pair {}".format(
         action.getAction(),
-        action.getQuantity(),
+        self.correctQuantity(action.getQuantity(), action.getPair()),
         action.getPair(),
       ))
     self.logger.info("--------------------------")
@@ -87,8 +92,8 @@ class ComputeWorker (StoppableThread):
     self.logger.debug("--> Executing deal")
     for i, action in enumerate(deal.getActions()):
       buy_sell = action.getAction()
-      qty = action.getQuantity()
       pair = action.getPair()
+      qty = self.correctQuantity(action.getQuantity(), pair)
       if buy_sell == "BUY":
         try:
           self.logger.info ("#{}: Buying {} from symbol {}".format(i+1, qty, pair))
