@@ -43,6 +43,7 @@ class bTrader (StoppableThread):
     self.__client             = None  # Client
     self.__info               = {}    # Got from Binance API
     self.__symbols            = []    # List of TradingPair (all of them)
+    self.__stepDict           = {}    # Dict of steps of all symbols (all of them)
     self.__base               = ""    # Base coin (from self.__config)
     self.__relationships      = []    # List of TriangularRelationship
     self.__relationshipLock   = None  # Lock for the relationship queue
@@ -115,6 +116,8 @@ class bTrader (StoppableThread):
     try:
       self.__info = self.__client.get_exchange_info()
       self.__symbols = [TradingPair(s) for s in self.__info['symbols'] if s['status'] == 'TRADING']
+      for pair in self.__symbols:
+        self.__stepDict[pair.symbol] = pair.step
       self.logger.info("Found {} market pairs".format(len(self.__symbols)))
     except Exception as e:
       self.logger.critical("Failed to get market pairs")
@@ -247,6 +250,7 @@ class bTrader (StoppableThread):
         trading_queue = self.__tradingQueue,
         client = self.__client,
         counter = self.__tradingCount,
+        stepDict = self.__stepDict,
       )
       worker.setDaemon(True)
       worker.start()
